Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(255)

Unified Diff: ui/gfx/display.h

Issue 10546158: Remove --default-device-scale-factor (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: . Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ui/base/ui_base_switches.cc ('k') | ui/gfx/display.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/gfx/display.h
diff --git a/ui/gfx/display.h b/ui/gfx/display.h
index 13aaa8f539f19941ca27b3475484985db2b2e044..0bc2630bd1397e2f167a545a8e6e681cd5c40150 100644
--- a/ui/gfx/display.h
+++ b/ui/gfx/display.h
@@ -19,9 +19,9 @@ namespace gfx {
// system, not in backing pixels.
class UI_EXPORT Display {
public:
- // Returns the default value for the device scale factor, which is
- // given by "--default-device-scale-factor".
- static float GetDefaultDeviceScaleFactor();
+ // Returns the forced device scale factor, which is given by
+ // "--force-device-scale-factor".
+ static float GetForcedDeviceScaleFactor();
// Creates a display with invalid id(-1) as default.
Display();
« no previous file with comments | « ui/base/ui_base_switches.cc ('k') | ui/gfx/display.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698